@@ -15,12 +15,12 @@ __all__ = [
 # Standard
 
 from functools import (
-    update_wrapper as _update_wrapper,
-    wraps as _wraps
+    update_wrapper as _ft_update_wrapper,
+    wraps as _ft_wraps
 )
 
 from re import (
-    search as _search
+    search as _re_search
 )
 
 from threading import (
@@ -75,7 +75,7 @@ class cached_property(property):
         self._func_name = None
         self._lock = _RLock()
 
-        _update_wrapper(self, fget)
+        _ft_update_wrapper(self, fget)
 
     def __set_name__(self, owner, name):
 
@@ -152,7 +152,7 @@ def aliased(aliased_class):
 
     def wrapper(func):
 
-        @_wraps(func)
+        @_ft_wraps(func)
         def inner(self, *args, **kwargs):
             return func(self, *args, **kwargs)
 
@@ -182,7 +182,7 @@ def aliased(aliased_class):
         if len(set(aliases_flat)) < len(aliases_flat):
             raise AttributeError('Aliases must be unique and cannot be shared among different class members.')
 
-        if any(not _search(r'^[a-z][a-z0-9]*(?:_[a-z0-9]+)*$', a) for a in aliases_flat):
+        if any(not _re_search(r'^[a-z][a-z0-9]*(?:_[a-z0-9]+)*$', a) for a in aliases_flat):
             raise ValueError('Aliases cannot start with an underscore character and must be compliant with PEP8 naming conventions.')
 
         if any(a in member_names for a in aliases_flat):
